Beautiful Soup is a library that makes it easy to scrape information
from web pages. It sits atop an HTML or XML parser, providing Pythonic
idioms for iterating, searching, and modifying the parse tree.

# Discontinuation notice

You should use the 'beautifulsoup4' package instead of this package.

Development on the 3.x series of Beautiful Soup ended in 2011, and the
series will be discontinued on January 1, 2021, one year after the
Python 2 sunsetting date. At some point after that, the
'beautifulsoup' pip package will be updated to a recent version of
Beautiful Soup. This will free up the 'beautifulsoup' package name to
be used by a more recent release.

If you're relying on version 3 of Beautiful Soup, you really ought to
port your code to Python 3. A relatively small part of this work will
be migrating your Beautiful Soup code to Beautiful Soup 4.
